/************************************************************************/
/* 		This code is part of 'CutterFF'				*/
/*		a tool for cutting video files with 'FFmpeg' and 'GTK'	*/
/*		Copyright (c) 2017 .. 2019 Harald Foerster		*/
/*		(harald_foerster@users.sourceforge.net)			*/
/*		Distributed under GPL 2 or later			*/
/************************************************************************/

#ifndef CFF_TOOLS_GTK__H
#define CFF_TOOLS_GTK__H

#include <gtk/gtk.h>

#define GUI_LIST_ROW_HEIGHT_MIN	16

typedef struct
{
	GtkListStore		*store;
	GtkTreeView		*view;
	GtkTreeSelection	*selection;

} cff_ListStore_t;

typedef struct
{
	GtkWidget	*topwin;	/* window with focus */
	GtkWidget	*mainwin;	/* this (cff_gui-gtk.c) window */

} cff_windata_t;

extern cff_windata_t gWindata;


/*
	------------
	 Prototypes
	------------
*/

GtkWidget *guitl_window_new(GtkWidget *child, gint border);
GtkWidget *guitl_window_new_gettext(const gchar *title, GtkWidget *child, gint border);
void       guitl_window_set_title_filename(GtkWidget *window, const gchar *title);
void       guitl_window_setup(GtkWidget *widget, gint prop);
gboolean   guitl_window_test_size(GtkWindow *window, gint width, gint height);
GtkWidget *guitl_scrolled_window_new(GtkWidget *container, gint wmin, gint hmin, gint policy);

void guitl_dialog_set_modal(GtkWidget *dialog, GtkWidget *parent, GtkWidget **menu);
void guitl_dialog_info(const gchar *text, GtkWidget **mbar);
void guitl_dialog_error(const gchar *text, GtkWidget **mbar);
void guitl_dialog_warning(const gchar *text, GtkWidget **mbar);
gint guitl_dialog_warning_2btn(const gchar *text, const gchar *btn_no, const gchar *btn_yes, GtkWidget **mbar);

GtkWidget *guitl_dialog_new_gettext_2btn(const gchar *title, const gchar *btn_no, const gchar *btn_yes, GtkWidget *parent);
GtkWidget *guitl_label_new_gettext(const gchar *str);
GtkWidget *guitl_menu_item_new_gettext(const gchar *label);
GtkWidget *guitl_check_menu_item_new_gettext(const gchar *label);
GtkWidget *guitl_frame_new_add_child_gettext(const gchar *title, GtkWidget *child);
GtkWidget *guitl_check_button_new_gettext(const gchar *label);
GtkWidget *guitl_vbox_add_check_button_gettext(GtkWidget *vbox, const gchar *label);
GtkWidget *guitl_hbox_add_button(GtkWidget *hbox, const gchar *text, GCallback func, gpointer data);
GtkWidget *guitl_vbox_add_button(GtkWidget *vbox, const gchar *text, GCallback func, gpointer data);
GtkWidget *guitl_hbox_add_button_gettext(GtkWidget *hbox, const gchar *text, GCallback func, gpointer data);
GtkWidget *guitl_vbox_add_button_gettext(GtkWidget *vbox, const gchar *text, GCallback func, gpointer data);
GtkWidget *guitl_hbutton_box_new(GtkWidget *parent, gint spacing, GtkButtonBoxStyle layout);
GtkWidget *guitl_button_box_add_button(GtkWidget *button_box, const gchar *text, GCallback func, gpointer data);

#if GTK_MAJOR_VERSION > 2
GtkWidget *guitl_hgrid_new(gboolean homogeneous, gint spacing);
GtkWidget *guitl_vgrid_new(gboolean homogeneous, gint spacing);
#endif

/* Misc */
int   tl_is_ascii_str(const char *str);
char *tl_replace_non_ascii_chars_in_str(char *str);
int   tl_file_exists(const char *path);

const char *tl_get_filename(const char *path);

#ifdef BUILD_MINGW
void file_path_dos_to_unix(char *path);
void file_path_unix_to_dos(char *path);
#endif

#endif /* CFF_TOOLS_GTK__H */
